@@ -9,9 +9,7 @@ from instaui.runtime import get_app_slot
 class PluginDependencyInfo:
     name: str = field(hash=True)
     esm: Path = field(hash=False)
-    externals: Optional[list[Path]] = field(
-        default_factory=list, compare=False, hash=False
-    )
+    externals: dict[str, Path] = field(default_factory=dict, compare=False, hash=False)
     css: list[Path] = field(default_factory=list, compare=False, hash=False)
 
 
@@ -19,10 +17,10 @@ def register_plugin(
     name: str,
     esm: Path,
     *,
-    externals: Optional[list[Path]] = None,
+    externals: Optional[dict[str, Path]] = None,
     css: Optional[list[Path]] = None,
 ):
-    info = PluginDependencyInfo(f"plugin/{name}", esm, externals or [], css or [])
+    info = PluginDependencyInfo(f"plugin/{name}", esm, externals or {}, css or [])
 
     get_app_slot().use_plugin_dependency(info)
     return info
