@@ -1,7 +1,7 @@
 from __future__ import annotations
 import typing
 from pathlib import Path
-from urllib.parse import quote
+from urllib.parse import quote, urlparse
 import base64
 
 
@@ -21,3 +21,10 @@ def normalize_path_to_base64_url(path: typing.Optional[Path], prefix: str):
     if path is None:
         return None
     return f"{prefix},{base64.b64encode(path.read_bytes()).decode('utf-8')}"
+
+
+def is_url(maybe_url: typing.Union[str, Path]) -> bool:
+    if isinstance(maybe_url, Path):
+        return False
+    parsed = urlparse(maybe_url)
+    return parsed.scheme in ("http", "https")
